@@ -31,18 +31,16 @@ class TextQueryTestBackend(TextQueryBackend):
         False: "0",
     }
 
-    startswith_expression : ClassVar[str] = "{field} startswith \"{value}\""
-    endswith_expression   : ClassVar[str] = "{field} endswith \"{value}\""
-    contains_expression   : ClassVar[str] = "{field} contains \"{value}\""
-    wildcard_match_expression : ClassVar[str] = "{field} match \"{value}\""
+    startswith_expression : ClassVar[str] = "{field} startswith {value}"
+    endswith_expression   : ClassVar[str] = "{field} endswith {value}"
+    contains_expression   : ClassVar[str] = "{field} contains {value}"
+    wildcard_match_expression : ClassVar[str] = "{field} match {value}"
 
     re_expression : ClassVar[str] = "{field}=/{regex}/"
     re_escape_char : ClassVar[str] = "\\"
     re_escape : ClassVar[Tuple[str]] = ("/", "bar")
 
-    cidr_expression : ClassVar[str] = "{field}={value}"
-    cidr_in_list_expression : ClassVar[str] = "{field} in ({list})"
-    cidr_wildcard : ClassVar[str] = None
+    cidr_expression : ClassVar[str] = "cidrmatch('{field}', \"{value}\")"
 
     compare_op_expression : ClassVar[str] = "{field}{operator}{value}"
     compare_operators : ClassVar[Dict[SigmaCompareExpression.CompareOperators, str]] = {
@@ -62,7 +60,7 @@ class TextQueryTestBackend(TextQueryBackend):
     and_in_operator : ClassVar[Optional[str]] = "contains-all"
     list_separator : ClassVar[str] = ", "
 
-    unbound_value_str_expression : ClassVar[str] = '_="{value}"'
+    unbound_value_str_expression : ClassVar[str] = '_={value}'
     unbound_value_num_expression : ClassVar[str] = '_={value}'
     unbound_value_re_expression : ClassVar[str] = '_=/{value}/'
 
