@@ -1,6 +1,7 @@
 from abc import ABC, abstractmethod
+from functools import partial
 from sigma.conditions import ConditionOR, SigmaCondition
-from typing import Any, Iterable, List, Dict, Optional, Union, Pattern, Iterator
+from typing import Any, Iterable, List, Dict, Optional, Set, Union, Pattern, Iterator
 from dataclasses import dataclass, field
 import dataclasses
 import random
@@ -27,7 +28,7 @@ class Transformation(ABC):
     @abstractmethod
     def apply(self, pipeline : "sigma.processing.pipeline.ProcessingPipeline", rule : SigmaRule) -> None:
         """Apply transformation on Sigma rule."""
-        self.pipeline = pipeline        # make pipeline accessible from all further options in class property
+        self.pipeline : "sigma.processing.pipeline.ProcessingPipeline" = pipeline        # make pipeline accessible from all further options in class property
         self.processing_item_applied(rule)
 
     def set_processing_item(self, processing_item : "sigma.processing.pipeline.ProcessingItem"):
@@ -37,6 +38,7 @@ class Transformation(ABC):
         """Mark detection item or detection as applied."""
         d.add_applied_processing_item(self.processing_item)
 
+@dataclass
 class DetectionItemTransformation(Transformation):
     """
     Iterates over all detection items of a Sigma rule and calls the apply_detection_item method
@@ -76,6 +78,41 @@ class DetectionItemTransformation(Transformation):
         for detection in rule.detection.detections.values():
             self.apply_detection(detection)
 
+@dataclass
+class FieldMappingTransformationBase(DetectionItemTransformation):
+    """
+    Transformation that is applied to detection items and additionally the field list of a Sigma
+    rule.
+    """
+    @abstractmethod
+    def apply_field_name(self, field : str) -> List[str]:
+        """
+        Apply field name transformation to a field list item of a Sigma rule. It must always return
+        a list of strings that are expanded into a new field list.
+        """
+
+    def _apply_field_name(self, pipeline: "sigma.processing.pipeline.ProcessingPipeline", field : str) -> List[str]:
+        """
+        Evaluate field name conditions and perform transformation with apply_field_name() method if
+        condition matches, else return original value.
+        """
+        if self.processing_item is None or self.processing_item.match_field_name(pipeline, field):
+            result = self.apply_field_name(field)
+            if self.processing_item is not None:
+                pipeline.track_field_processing_items(field, result, self.processing_item.identifier)
+            return result
+        else:
+            return [ field ]
+
+    def apply(self, pipeline: "sigma.processing.pipeline.ProcessingPipeline", rule: SigmaRule) -> None:
+        _apply_field_name = partial(self._apply_field_name, pipeline)
+        rule.fields = [
+            item
+            for mapping in map(_apply_field_name, rule.fields)
+            for item in mapping
+        ]
+        return super().apply(pipeline, rule)
+
 @dataclass
 class ValueTransformation(DetectionItemTransformation):
     """
@@ -129,6 +166,7 @@ class ValueTransformation(DetectionItemTransformation):
         The type annotation of the val argument is used to skip incompatible values.
         """
 
+@dataclass
 class ConditionTransformation(Transformation):
     """
     Iterates over all rule conditions and calls the apply_condition method for each condition. Automatically
@@ -150,13 +188,14 @@ class ConditionTransformation(Transformation):
 
 ### Transformations ###
 @dataclass
-class FieldMappingTransformation(DetectionItemTransformation):
+class FieldMappingTransformation(FieldMappingTransformationBase):
     """Map a field name to one or multiple different."""
     mapping : Dict[str, Union[str, List[str]]]
 
     def apply_detection_item(self, detection_item : SigmaDetectionItem):
         if (field_name := detection_item.field) in self.mapping:
             mapping = self.mapping[field_name]
+            self.pipeline.field_mappings.add_mapping(field_name, mapping)
             if isinstance(mapping, str):    # 1:1 mapping, map field name of detection item directly
                 detection_item.field = self.mapping[field_name]
                 self.processing_item_applied(detection_item)
@@ -166,6 +205,13 @@ class FieldMappingTransformation(DetectionItemTransformation):
                     for field in mapping
                 ], item_linking=ConditionOR)
 
+    def apply_field_name(self, field: str) -> Union[str, List[str]]:
+        mapping = self.mapping.get(field, field)
+        if isinstance(mapping, str):
+            return [mapping]
+        else:
+            return mapping
+
 @dataclass
 class DropDetectionItemTransformation(DetectionItemTransformation):
     """Deletes detection items. This should only used in combination with a detection item
@@ -189,29 +235,37 @@ class DropDetectionItemTransformation(DetectionItemTransformation):
             ))
 
 @dataclass
-class AddFieldnameSuffixTransformation(DetectionItemTransformation):
+class AddFieldnameSuffixTransformation(FieldMappingTransformationBase):
     """
     Add field name suffix.
     """
     suffix : str
 
     def apply_detection_item(self, detection_item : SigmaDetectionItem):
-        if type(detection_item.field) is str:
+        if type(orig_field := detection_item.field) is str:
             detection_item.field += self.suffix
+            self.pipeline.field_mappings.add_mapping(orig_field, detection_item.field)
         self.processing_item_applied(detection_item)
 
+    def apply_field_name(self, field: str) -> List[str]:
+        return [ field + self.suffix ]
+
 @dataclass
-class AddFieldnamePrefixTransformation(DetectionItemTransformation):
+class AddFieldnamePrefixTransformation(FieldMappingTransformationBase):
     """
     Add field name prefix.
     """
     prefix : str
 
     def apply_detection_item(self, detection_item : SigmaDetectionItem):
-        if type(detection_item.field) is str:
+        if type(orig_field := detection_item.field) is str:
             detection_item.field = self.prefix + detection_item.field
+            self.pipeline.field_mappings.add_mapping(orig_field, detection_item.field)
         self.processing_item_applied(detection_item)
 
+    def apply_field_name(self, field: str) -> List[str]:
+        return [ self.prefix + field ]
+
 @dataclass
 class PlaceholderIncludeExcludeMixin:
     include : Optional[List[str]] = field(default=None)
